@@ -54,12 +54,17 @@ void              panel_application_load              (PanelApplication  *applic
 void              panel_application_save              (PanelApplication  *application,
                                                        PanelSaveTypes     save_types);
 
+void              panel_application_save_window       (PanelApplication  *application,
+                                                       PanelWindow       *window,
+                                                       PanelSaveTypes     save_types);
+
 void              panel_application_take_dialog       (PanelApplication  *application,
                                                        GtkWindow         *dialog);
 
 void              panel_application_destroy_dialogs   (PanelApplication  *application);
 
 void              panel_application_add_new_item      (PanelApplication  *application,
+                                                       PanelWindow       *window,
                                                        const gchar       *plugin_name,
                                                        gchar            **arguments);
 
