@@ -20,6 +20,10 @@
 #include <config.h>
 #endif
 
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+
 #include <exo/exo.h>
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -136,6 +140,9 @@ struct _PanelPreferencesDialog
 
   /* changed signal for the output selector */
   gulong            output_changed_handler_id;
+
+  /* plug in which the dialog is embedded */
+  GtkWidget        *socket_plug;
 };
 
 
@@ -283,6 +290,10 @@ panel_preferences_dialog_finalize (GObject *object)
   /* free bindings list */
   g_slist_free (dialog->bindings);
 
+  /* destroy possible pluggable dialog */
+  if (dialog->socket_plug != NULL)
+    gtk_widget_destroy (dialog->socket_plug);
+
   if (dialog->active != NULL)
     {
       if (dialog->items_changed_handler_id != 0)
@@ -426,12 +437,12 @@ panel_preferences_dialog_bindings_update (PanelPreferencesDialog *dialog)
   panel_preferences_dialog_bg_image_notified (dialog);
 
   /* get run mode of the driver (multiple screens or randr) */
+  screen = gtk_widget_get_screen (GTK_WIDGET (dialog->active));
   display = gtk_widget_get_display (GTK_WIDGET (dialog->active));
   n_screens = gdk_display_get_n_screens (display);
   n_monitors = 1;
   if (G_LIKELY (n_screens <= 1))
     {
-      screen = gtk_widget_get_screen (GTK_WIDGET (dialog->active));
       n_monitors = gdk_screen_get_n_monitors (screen);
     }
 
@@ -1020,6 +1031,11 @@ panel_preferences_dialog_item_move (GtkWidget              *button,
                                        GTK_WIDGET (provider),
                                        position + direction);
 
+          /* save the new ids */
+          panel_application_save_window (dialog->application,
+                                         dialog->active,
+                                         SAVE_PLUGIN_IDS);
+
           /* unblock the changed signal */
           g_signal_handler_unblock (G_OBJECT (itembar), dialog->items_changed_handler_id);
 
@@ -1197,9 +1213,15 @@ panel_preferences_dialog_item_row_changed (GtkTreeModel           *model,
 
   /* move the item on the panel */
   if (position != store_position)
-    panel_itembar_reorder_child (PANEL_ITEMBAR (itembar),
-                                 GTK_WIDGET (provider),
-                                 store_position);
+    {
+      panel_itembar_reorder_child (PANEL_ITEMBAR (itembar),
+                                   GTK_WIDGET (provider),
+                                   store_position);
+
+      panel_application_save_window (dialog->application,
+                                     dialog->active,
+                                     SAVE_PLUGIN_IDS);
+    }
 }
 
 
@@ -1266,13 +1288,28 @@ panel_preferences_dialog_item_selection_changed (GtkTreeSelection       *selecti
 
 
 
-void
-panel_preferences_dialog_show (PanelWindow *active)
+static void
+panel_preferences_dialog_plug_deleted (GtkWidget *plug)
+{
+  g_signal_handlers_disconnect_by_func (G_OBJECT (plug),
+      G_CALLBACK (panel_preferences_dialog_plug_deleted), NULL);
+
+  g_object_unref (G_OBJECT (dialog_singleton));
+}
+
+
+
+static void
+panel_preferences_dialog_show_internal (PanelWindow     *active,
+                                        GdkNativeWindow  socket_window)
 {
   gint         panel_id = 0;
   GObject     *window, *combo;
   GdkScreen   *screen;
   GSList      *windows;
+  GtkWidget   *plug;
+  GObject     *plug_child;
+  GtkWidget   *content_area;
 
   panel_return_if_fail (active == NULL || PANEL_IS_WINDOW (active));
 
@@ -1295,17 +1332,6 @@ panel_preferences_dialog_show (PanelWindow *active)
         active = g_slist_nth_data (windows, 0);
     }
 
-  /* get the active screen */
-  if (G_LIKELY (active != NULL))
-    screen = gtk_widget_get_screen (GTK_WIDGET (active));
-  else
-    screen = gdk_screen_get_default ();
-
-  /* show the dialog on the same screen as the panel */
-  window = gtk_builder_get_object (GTK_BUILDER (dialog_singleton), "dialog");
-  panel_return_if_fail (GTK_IS_WIDGET (window));
-  gtk_window_set_screen (GTK_WINDOW (window), screen);
-
   /* select the active window in the dialog */
   combo = gtk_builder_get_object (GTK_BUILDER (dialog_singleton), "panel-combobox");
   panel_return_if_fail (GTK_IS_WIDGET (combo));
@@ -1313,20 +1339,86 @@ panel_preferences_dialog_show (PanelWindow *active)
   if (!panel_preferences_dialog_panel_combobox_rebuild (dialog_singleton, panel_id))
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 
-  gtk_window_present (GTK_WINDOW (window));
+  window = gtk_builder_get_object (GTK_BUILDER (dialog_singleton), "dialog");
+  panel_return_if_fail (GTK_IS_WIDGET (window));
+  plug_child = gtk_builder_get_object (GTK_BUILDER (dialog_singleton), "plug-child");
+  panel_return_if_fail (GTK_IS_WIDGET (plug_child));
+
+  /* check if we need to remove the window from the plug */
+  if (dialog_singleton->socket_plug != NULL)
+    {
+      panel_return_if_fail (GTK_IS_PLUG (dialog_singleton->socket_plug));
+
+      /* move the vbox to the dialog */
+      content_area = gtk_dialog_get_content_area (GTK_DIALOG (window));
+      gtk_widget_reparent (GTK_WIDGET (plug_child), content_area);
+      gtk_widget_show (GTK_WIDGET (plug_child));
+
+      /* destroy the plug */
+      plug = dialog_singleton->socket_plug;
+      dialog_singleton->socket_plug = NULL;
+
+      g_signal_handlers_disconnect_by_func (G_OBJECT (plug),
+          G_CALLBACK (panel_preferences_dialog_plug_deleted), NULL);
+      gtk_widget_destroy (plug);
+    }
+
+  if (socket_window == 0)
+    {
+      /* show the dialog on the same screen as the panel */
+      if (G_LIKELY (active != NULL))
+        screen = gtk_widget_get_screen (GTK_WIDGET (active));
+      else
+        screen = gdk_screen_get_default ();
+      gtk_window_set_screen (GTK_WINDOW (window), screen);
+
+      gtk_window_present (GTK_WINDOW (window));
+    }
+  else
+    {
+      /* hide window */
+      gtk_widget_hide (GTK_WIDGET (window));
+
+      /* create a new plug */
+      plug = gtk_plug_new (socket_window);
+      g_signal_connect (G_OBJECT (plug), "delete-event",
+          G_CALLBACK (panel_preferences_dialog_plug_deleted), NULL);
+      dialog_singleton->socket_plug = plug;
+      gtk_widget_show (plug);
+
+      /* move the vbox in the plug */
+      gtk_widget_reparent (GTK_WIDGET (plug_child), plug);
+      gtk_widget_show (GTK_WIDGET (plug_child));
+    }
 }
 
 
 
 void
-panel_preferences_dialog_show_from_id (gint panel_id)
+panel_preferences_dialog_show (PanelWindow *active)
+{
+  panel_return_if_fail (active == NULL || PANEL_IS_WINDOW (active));
+  panel_preferences_dialog_show_internal (active, 0);
+}
+
+
+
+void
+panel_preferences_dialog_show_from_id (gint         panel_id,
+                                       const gchar *socket_id)
 {
   PanelApplication *application;
   PanelWindow      *window;
+  GdkNativeWindow   socket_window = 0;
+
+  /* x11 windows are ulong on 64 bit platforms
+   * or uint32 on other platforms */
+  if (socket_id != NULL)
+    socket_window = (GdkNativeWindow) strtoul (socket_id, NULL, 0);
 
   application = panel_application_get ();
   window = panel_application_get_window (application, panel_id);
-  panel_preferences_dialog_show (window);
+  panel_preferences_dialog_show_internal (window, socket_window);
   g_object_unref (G_OBJECT (application));
 }
 
